Module compiler

Module compiler 

This module provides utilities for analyzing and manipulating sequences of Microcode operations in order to transform opcodes into rust code that executes those opcodes.

Modules

args
Provides utilities for working with args to the microcode.
direct_executor_generation
Provides tools for generating the Direct Executor.
instr
Provides instructions, which are the definitions of what opcodes do.
state_executor_generation
Provides utilities for codegenerating the state-machine executor.
variables
Types for managing variables in generated executor implementations.

Enums

OperationType
Which type of microcode operation this is.