Module args

Module args 

Provides utilities for working with args to the microcode.

Structs

DynLiteral
A literal with object-safe clone-ability.

Enums

Arg
An argument to a microcode operator.

Traits

Literal
Helper for converting a type to a literal representation.

Type Aliases

CrateFetcher
Function type used to look up crate names for literal values.