pub enum OperationType {
Function {
path: TokenStream,
},
Extern,
}Expand description
Which type of microcode operation this is.
Variants
Function
Microcode operation is a pure function.
Fields

path: TokenStreamPath to the function that defines the microcode operation, relative to the module that the Microcode type is defined in.
Extern
Microcode operation is externally defined.