InstrBuilder

Struct InstrBuilder 

pub struct InstrBuilder { /* private fields */ }
Builder for microcode.

Implementations

Source

impl InstrBuilder

pub fn new() -> Self

Create a new empty builder.

pub fn first(code: impl Into<InstrBuilder>) -> Self

Create a new builder with the given initial instructions.

pub fn yield() -> Self

Create a builder containing just a yield.

pub fn cond( code_if_true: impl Into<InstrBuilder>, code_if_false: impl Into<InstrBuilder>, ) -> Self

pub fn if_true(code_if_true: impl Into<InstrBuilder>) -> Self

Pop a single byte boolean off the microcode stack and run this if it is true.

pub fn if_false(code_if_false: impl Into<InstrBuilder>) -> Self

Pop a single byte boolean off the microcode stack and run this if it is false.

pub fn then_cond( self, code_if_true: impl Into<InstrBuilder>, code_if_false: impl Into<InstrBuilder>, ) -> Self

Chooses between two branches depending on whether the u8 on top of the stack is non-zero.

pub fn then_if_true(self, code_if_true: impl Into<InstrBuilder>) -> Self

Run the given code if the u8 on top of the stack is non-zero.

pub fn then_if_false(self, code_if_false: impl Into<InstrBuilder>) -> Self

Run the given code if the u8 on top of the stack is zero.

pub fn read<R: MicrocodeReadable>(from: R) -> Self

Create a single-step microcode that reads from the specified source.

pub fn write<W: MicrocodeWritable>(to: W) -> Self

Create a single-step microcode that writes to the specified source.

pub fn then(self, code: impl Into<InstrBuilder>) -> Self

Add the given instruction or instructions to the end of this microcode.

pub fn then_yield(self) -> Self

Add a yield to the end of the builder.

pub fn then_read<R: MicrocodeReadable>(self, from: R) -> Self

Add a read to the end of the builder.

pub fn then_write<W: MicrocodeWritable>(self, to: W) -> Self

Add a write to the end of the builder.

pub fn build(self, id: InstrId) -> InstrDef

Build an instruction from this microcode, adding the id for the instruction.