ElementPath

Struct ElementPath 

pub struct ElementPath { /* private fields */ }
A path to a particular child Element.

Implementations

Source

impl ElementPath

pub const EMPTY: &ElementPath

An empty element path.

pub const fn from_slice<'p>(slice: &'p [ElementSelector]) -> &'p Self

Create an ElementPath ref from a slice of ElementSelector.

pub fn from_mut_slice<'p>(slice: &'p mut [ElementSelector]) -> &'p mut Self

Create a mut ElementPath ref from a mut slice of ElementSelector.

pub const fn len(&self) -> usize

Gets the number of selectors in this ElementPath.

pub fn to_buf(&self) -> ElementPathBuf

Creates an ElementPathBuf from this ElementPath.

pub const fn as_slice(&self) -> &[ElementSelector]

Get this ElementPath as a slice.

pub fn as_mut_slice(&mut self) -> &mut [ElementSelector]

Get this ElementPath as a mutable slice.

pub fn iter(&self) -> Iter<'_, ElementSelector>

Get an iterator over the selectors in this path.

pub fn iter_mut(&mut self) -> IterMut<'_, ElementSelector>

Get an iterator over mutable selectors in this path.

pub const fn parent(&self) -> Option<&ElementPath>

Get the parent of this ElementPath if any. Returns None for the root (empty) path.

pub const fn last(&self) -> Option<ElementSelector>

Gets the last selector from the ElementPath.

pub fn last_mut(&mut self) -> Option<&mut ElementSelector>

Mutably gets the last selector from the ElementPath.