ElementPathBuf

Struct ElementPathBuf 

pub struct ElementPathBuf { /* private fields */ }
A path to a particular child Element.

Implementations

Source

impl ElementPathBuf

pub fn new() -> Self

Create a new empty element path buf.

pub fn from_path(path: &ElementPath) -> Self

Create a new selector by copying the given path.

pub fn as_path(&self) -> &ElementPath

Get this ElementPathBuf as an ElementPath slice.

pub fn as_mut_path(&mut self) -> &mut ElementPath

Get this ElementPathBuf as a mut ElementPath slice.

pub fn push<S>(&mut self, selector: S)

Push the given selector onto the end of this path.

pub fn append<P>(&mut self, path: P)
where P: ElementIndex,

Append another ElementIndex to the end of this path.

pub fn pop(&mut self) -> Option<ElementSelector>

Pop the last element off of this path selector, transforming it into its parent. Returns the ElementSelector that was popped, or None if the path was already the root.

Methods from Deref<Target = ElementPath>

pub const EMPTY: &ElementPath

pub fn len(&self) -> usize

Gets the number of selectors in this ElementPath.

pub fn to_buf(&self) -> ElementPathBuf

Creates an ElementPathBuf from this ElementPath.

pub fn as_slice(&self) -> &[ElementSelector]

Get this ElementPath as a slice.

pub fn as_mut_slice(&mut self) -> &mut [ElementSelector]

Get this ElementPath as a mutable slice.

pub fn iter(&self) -> Iter<'_, ElementSelector>

Get an iterator over the selectors in this path.

pub fn iter_mut(&mut self) -> IterMut<'_, ElementSelector>

Get an iterator over mutable selectors in this path.

pub fn parent(&self) -> Option<&ElementPath>

Get the parent of this ElementPath if any. Returns None for the root (empty) path.

pub fn last(&self) -> Option<ElementSelector>

Gets the last selector from the ElementPath.

pub fn last_mut(&mut self) -> Option<&mut ElementSelector>

Mutably gets the last selector from the ElementPath.