InstrStates

Struct InstrStates 

pub struct InstrStates { /* private fields */ }
The full set of states for an instruction.

Implementations

Source

impl InstrStates

pub fn new(instr: &InstrDef) -> Self

Build InstrStates for the given InstrDef.

pub fn get_state(&self, path: &ElementPath) -> Option<&State>

Get a state based on the path where that state starts.

pub fn state_starts( &self, ) -> impl Iterator<Item = &ElementPath> + DoubleEndedIterator + ExactSizeIterator + FusedIterator

Get an iterator over the paths where the various states start.

pub fn states( &self, ) -> impl Iterator<Item = (&ElementPath, &State)> + DoubleEndedIterator + ExactSizeIterator + FusedIterator

Get an iterator over all of the states along with their starting paths.

pub fn into_states( self, ) -> <BTreeMap<ElementPathBuf, State> as IntoIterator>::IntoIter

Consume this InstrStates producing an iterator over the paths and states.