pub struct StateBlock {
pub elements: Vec<StateElement>,
}Expand description
A block of state elements with variable assignments computed. Note that this block
does not create a new scope, unlike a Rust { block }.
Fields
elements: Vec<StateElement>Assigned elements.