pub struct VarAssignment {
pub var: VarId,
pub val: ValType,
}Expand description
A variable assignment number and the type of the microcode value held there.
Fields
var: VarIdID of the variable that is assigned.
val: ValTypeType of the value assigned to that variable ID.