pub struct DecSp;Expand description
Helper for decrementing the stack pointer and reading it.
When used as a MicrocodeReadable, DecSp will decrement the value of the stack
pointer in place and read the value into the microcode stack.