ServiceInterrupt

Struct ServiceInterrupt 

pub struct ServiceInterrupt;
Helper to build microcode to service an interrupt.

Checks if an interrupt should be serviced, and if so performs the hidden isr instruction to jump to the interrupt handler. Runs FetchNextInstruction when done to reset and load the instruction at the microcode handler address