pub struct SpInc;Expand description
Helper for reading the stack pointer and incrementing it.
When used as a MicrocodeReadable, IncSp will load the value of the stack pointer
to the microcode stack and then increment the stack pointer in-place.