pub fn intersperse(addr: u16, val: u16) -> (u8, u16, u8, u16)Expand description
Takes a u16 address off the stack followed by a u16 value, then splits the value into separate bytes and pushes them on the stack in the order: u8 high, u16 addr, u8 low, u16 addr. This is useful for performing a 16 bit write where the low byte is written first.