pub fn offset_addr(addr: u16, offset: u8) -> (u16, Flags)
Pops a 16 bit address off the stack followed by an 8 bit offset below it. Applies address offsetting and pushes the new address followed by the flags on top.