pub struct MicrocodeDescriptor {
pub name: String,
pub args: Vec<Arg<ValType>>,
pub returns: Vec<ValType>,
pub optype: OperationType,
}Expand description
Provides descriptive informaton about an instruction from the microcode.
Fields
name: StringName of the opcode.
args: Vec<Arg<ValType>>Arguments to this operator. Stack arguments are in the order they should be popped off the stack. Field arguments are provided as literals.
returns: Vec<ValType>Values returned from this operator. All of them go on the stack. Provided in the order they should be pushed onto the stack.
optype: OperationTypeWhich type of operation this is (an extern or a pure function).