Module opcode

Module opcode 

Provides the Opcode and CBOpcode types, which define the opcodes available on the gbz80 CPU.

Modules

args
These are types which are used as arguments to the Opcodes and CBOpcodes.
defs
Provides the definitions of the opcodes in terms of microcode.

Structs

CBOpcode
Opcodes that come after a CB prefix opcode.
InternalFetch
Represents the internal-fetch opcode which is used to begin every instruction cycle.

Enums

CBOperation
Type of operation performed in a CB prefix opcode.
Opcode
Parsed Opcode, not including any arguments that may be loaded from immediates, nor any follow-up ops if the operation is a prefixed op.