Module args

Module args 

These are types which are used as arguments to the Opcodes and CBOpcodes.

Enums

AluOp
ALU Operation type.
AluUnaryOp
Type of unary ALU operation. All ops here apply only to A and Flags.
ConditionCode
Conditional for conditional jump/conditional ret.
Operand8
8 bit operand. Either the source or destination of an 8 bit operation.
Operand16
16 bit operand.