pub enum AluUnaryOp {
RotateLeft8,
RotateLeft9,
RotateRight8,
RotateRight9,
DecimalAdjust,
SetCarryFlag,
Compliment,
ComplimentCarryFlag,
}Expand description
Type of unary ALU operation. All ops here apply only to A and Flags.
Variants
RotateLeft8
8-bit left rotate. Bit 7 goes to both the carry and bit 0.
RotateLeft9
9-bit left rotate. Bit 7 goes to carry and carry goes to bit 0.
RotateRight8
8-bit right rotate. Bit 0 goes to both the carry and bit 7.
RotateRight9
9-bit left rotate. Bit 0 goes to carry and carry goes to bit 7.
DecimalAdjust
Helper for doing binary-coded-decimal. Adjusts the hex didgits to keep both nybbles in range 0..=9 by adding 0x06 and/or 0x60 to push the digit to the next nybble.
SetCarryFlag
Sets the carry flag.
Compliment
Inverts the Accumulator.
ComplimentCarryFlag
Inverts the carry flag.