This module provides utilities for analyzing and manipulating sequences of
Microcode operations in order to transform opcodes
into rust code that executes those opcodes.
Modules
- args
- Provides utilities for working with args to the microcode.
- direct_
executor_ generation - Provides tools for generating the Direct Executor.
- instr
- Provides instructions, which are the definitions of what opcodes do.
- state_
executor_ generation - Provides utilities for codegenerating the state-machine executor.
- variables
- Types for managing variables in generated executor implementations.
Enums
- Operation
Type - Which type of microcode operation this is.