pub struct AssignedMicrocode {
pub microcode: Microcode,
pub conversions: Vec<Conversion>,
pub args: Vec<Arg<VarAssignment>>,
pub returns: Vec<VarAssignment>,
}Expand description
Microcode with required type conversions and variable assignments provided.
Fields
microcode: MicrocodeThe microcode to execute.
conversions: Vec<Conversion>Type conversions to apply before running the microcode for this operation.
args: Vec<Arg<VarAssignment>>Arguments to the microcode function, with the variables they will be pulled from.
returns: Vec<VarAssignment>Variables that will be assigned by the result.