pub trait MicrocodeReadable {
// Required method
fn to_read(self) -> InstrBuilder;
}Expand description
Allows a type that represents a target that can be read or written to be used with
.read or .then_read.
Required Methods
fn to_read(self) -> InstrBuilder
Implementors
impl MicrocodeReadable for Reg8
impl MicrocodeReadable for Reg16
impl MicrocodeReadable for Operand8
As a MicrocodeReadable, Operand8 will result in a u8 being pushed onto the microcode
stack from the appropriate source.
impl MicrocodeReadable for Operand16
As a MicrocodeReadable, Operand16 will result in a u16 being pushed onto the
microcode stack from the appropriate source.
impl MicrocodeReadable for Flags
When used as a MicrocodeReadable, Flags causes a read from the Flags register which applies the given mask to the set of flags being read. In effect it is an instruction to read just the specified flags and put zeroes for all others.
impl MicrocodeReadable for DecSp
impl MicrocodeReadable for GbStack16
When used as a MicrocodeReadable, GbStack16 acts as a pop operation. A 16 bit
value will be read out from the location of the stack pointer, and the stack pointer
will be incremented by 2 (the stack starts at the end of memory and moves down).