pub trait MicrocodeWritable {
// Required method
fn to_write(self) -> InstrBuilder;
}Expand description
Allows a type that represents a target that can be read or written to be used with
.write or .then_write.
Required Methods
fn to_write(self) -> InstrBuilder
Implementors
impl MicrocodeWritable for Reg8
impl MicrocodeWritable for Reg16
impl MicrocodeWritable for Operand8
As a MicrocodeWritable, Operand8 will result in a u8 popped off of the stack and
written to the appropriate destination.
impl MicrocodeWritable for Operand16
As a MicrocodeWritable, Operand16 will result in a u16 popped off of the stack and
written to the appropriate destination.
impl MicrocodeWritable for Flags
When used as a MicrocodeWritable, Flags causes a write to the Flags register which applies the given mask to the set of flags being written. In effect it is an instruction to overwrite the specified flags.
impl MicrocodeWritable for GbStack16
When used as a MicrocodeWritable, GbStack16 acts as a push operation. A 16 bit
value will be popped from the microcode stack, the stack pointer will be decremented
by 2, and the value will be written to the new location of the stack pointer.