pub struct ElementPath { /* private fields */ }Expand description
A path to a particular child Element.
Implementations
Sourceimpl ElementPath
impl ElementPath
Sourcepub const EMPTY: &ElementPath
pub const EMPTY: &ElementPath
An empty element path.
Sourcepub const fn from_slice<'p>(slice: &'p [ElementSelector]) -> &'p Self
pub const fn from_slice<'p>(slice: &'p [ElementSelector]) -> &'p Self
Create an ElementPath ref from a slice of ElementSelector.
Sourcepub fn from_mut_slice<'p>(slice: &'p mut [ElementSelector]) -> &'p mut Self
pub fn from_mut_slice<'p>(slice: &'p mut [ElementSelector]) -> &'p mut Self
Create a mut ElementPath ref from a mut slice of ElementSelector.
Sourcepub const fn len(&self) -> usize
pub const fn len(&self) -> usize
Gets the number of selectors in this ElementPath.
Sourcepub fn to_buf(&self) -> ElementPathBuf
pub fn to_buf(&self) -> ElementPathBuf
Creates an ElementPathBuf from this ElementPath.
Sourcepub const fn as_slice(&self) -> &[ElementSelector]
pub const fn as_slice(&self) -> &[ElementSelector]
Get this ElementPath as a slice.
Sourcepub fn as_mut_slice(&mut self) -> &mut [ElementSelector]
pub fn as_mut_slice(&mut self) -> &mut [ElementSelector]
Get this ElementPath as a mutable slice.
Sourcepub fn iter(&self) -> Iter<'_, ElementSelector>
pub fn iter(&self) -> Iter<'_, ElementSelector>
Get an iterator over the selectors in this path.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, ElementSelector>
pub fn iter_mut(&mut self) -> IterMut<'_, ElementSelector>
Get an iterator over mutable selectors in this path.
Sourcepub const fn parent(&self) -> Option<&ElementPath>
pub const fn parent(&self) -> Option<&ElementPath>
Get the parent of this ElementPath if any. Returns None for the root (empty)
path.
Sourcepub const fn last(&self) -> Option<ElementSelector>
pub const fn last(&self) -> Option<ElementSelector>
Gets the last selector from the ElementPath.
Sourcepub fn last_mut(&mut self) -> Option<&mut ElementSelector>
pub fn last_mut(&mut self) -> Option<&mut ElementSelector>
Mutably gets the last selector from the ElementPath.