pub struct InstrStates { /* private fields */ }Expand description
The full set of states for an instruction.
Implementations
Sourceimpl InstrStates
impl InstrStates
Sourcepub fn get_state(&self, path: &ElementPath) -> Option<&State>
pub fn get_state(&self, path: &ElementPath) -> Option<&State>
Get a state based on the path where that state starts.
Sourcepub fn state_starts(
&self,
) -> impl Iterator<Item = &ElementPath> + DoubleEndedIterator + ExactSizeIterator + FusedIterator
pub fn state_starts( &self, ) -> impl Iterator<Item = &ElementPath> + DoubleEndedIterator + ExactSizeIterator + FusedIterator
Get an iterator over the paths where the various states start.
Sourcepub fn states(
&self,
) -> impl Iterator<Item = (&ElementPath, &State)> + DoubleEndedIterator + ExactSizeIterator + FusedIterator
pub fn states( &self, ) -> impl Iterator<Item = (&ElementPath, &State)> + DoubleEndedIterator + ExactSizeIterator + FusedIterator
Get an iterator over all of the states along with their starting paths.
Sourcepub fn into_states(
self,
) -> <BTreeMap<ElementPathBuf, State> as IntoIterator>::IntoIter
pub fn into_states( self, ) -> <BTreeMap<ElementPathBuf, State> as IntoIterator>::IntoIter
Consume this InstrStates producing an iterator over the paths and states.