Modules
- args
- Types which are used as arguments to the
Microcode. - combocodes
- Combo-codes are helper types which allow you to specify common sequences of microcode operations using a single value.
- defs
Microcodeis a set of simple instructions designed specifically for implementing the opcodes on the gbz80 processor used on the gameboy. These instructions operate on a stack of bytes called the microcode stack, which is separate from the gameboy’s stack. Each microcode operation pops some values off of the stack, computes a result, and pushes its results onto the stack.
Structs
- Microcode
Descriptor - Provides descriptive informaton about an instruction from the microcode.
Enums
- Microcode
Microcodeis a set of simple instructions designed specifically for implementing the opcodes on the gbz80 processor used on the gameboy. These instructions operate on a stack of bytes called the microcode stack, which is separate from the gameboy’s stack. Each microcode operation pops some values off of the stack, computes a result, and pushes its results onto the stack.- ValType