Combo-codes are helper types which allow you to specify common sequences of microcode operations using a single value.
Structs
- DecSp
- Helper for decrementing the stack pointer and reading it.
- GbStack16
- Helper struct for manipulating the GameBoy stack from microcode.
- Handle
Halt - Provides the CPU’s halt-handling behavior.
- HlDec
- Helper for reading HL and decrementing it.
- HlInc
- Helper for reading the HL and incrementing it.
- Immediate8
- 8-bit immediate value. Expands to code to fetch an 8-bit value from memory and increment the program counter.
- Immediate16
- 16-bit immediate value. Expands to code to fetch two 8-bit immediate values sequentially.
- Load
AndExecute - Helper to provide microcode for LoadAndExecute of an instruction, including halt-bug handling and enabling IME state ticking.
- Mem
- 8-bit read helper struct. Expands to a yield followed by an 8-bit read or write operation.
- Service
Interrupt - Helper to build microcode to service an interrupt.
- SpInc
- Helper for reading the stack pointer and incrementing it.