pub struct Immediate16;Expand description
16-bit immediate value. Expands to code to fetch two 8-bit immediate values sequentially.
Endianness is correct because we always push the lower byte of a LE word to the microcode stack first followed by the higher byte, which always keeps the word in gameboy LE byte order regardless of the running system endianness.