pub enum CBOperation {
RotateLeft8,
RotateLeft9,
RotateRight8,
RotateRight9,
ShiftLeft,
ShiftRight,
ShiftRightSignExt,
Swap,
TestBit(u8),
SetBit(u8),
ResetBit(u8),
}Expand description
Type of operation performed in a CB prefix opcode.
Variants
RotateLeft8
8-bit left rotate. Bit 7 goes to both the carry and bit 0.
RotateLeft9
9-bit left rotate. Bit 7 goes to carry and carry goes to bit 0.
RotateRight8
8-bit right rotate. Bit 0 goes to both the carry and bit 7.
RotateRight9
9-bit left rotate. Bit 0 goes to carry and carry goes to bit 7.
ShiftLeft
Shift left. Bit 7 gotes to carry, and 0 fills in Bit 0.
ShiftRight
Shift right. Bit 0 goes to carry, and 0 fills in Bit 7.
ShiftRightSignExt
Shift right with sign-extension. Bit 0 goes to carry, and Bit 7 is copied with its current value.
Swap
Swap the nybbles of the byte.
TestBit(u8)
Check if the given bit (given as an index in range 0..=7) is set in the operand.
SetBit(u8)
Sets the given bit (given as an index in range 0..=7) in the operand.
ResetBit(u8)
Clears the given bit (given as an index in range 0..=7) in the operand.